@@ -34,7 +34,7 @@
 #define MAX_NR_KEYMAPS NR_KEYMAPS
 #endif
 
-#define VERSION "0.88"
+#define VERSION "0.89"
 static int fd;
 
 char keymap_exists[MAX_NR_KEYMAPS];
@@ -115,7 +115,7 @@ void print_keysym(int code, char numeric) {
 	t = KTYP(code);
 	v = KVAL(code);
 	if (t > KT_LETTER) {
-	        printf("U%04x          ", code ^ 0xf000);
+	        printf("U+%04x          ", code ^ 0xf000);
 		return;
 	}
 	if (t == KT_LETTER) {
@@ -404,7 +404,7 @@ valid options are:
 	-f --full-table	don't use short-hand notations
 	   --funcs-only	display only the function key strings
 	   --keys-only	display only key bindings
-%s	-c --charset=iso-8859-{1,2,3,4,7,8}
+%s	-c --charset=iso-8859-{1,2,3,4,5,7,8}
 			interpret character action codes to be from the
 			specified character set
 ",
@@ -476,7 +476,7 @@ main (int argc, char *argv[]) {
 			case 'c':
 				if (strlen(optarg) != 10 || /* iso-8859-x */
 					strncmp(optarg, "iso-8859-", 9) ||
-					!index("123478", optarg[9]))
+					!index("1234578", optarg[9]))
 					usage();
 				charset = optarg[9] - '0';
 				printf("charset \"%s\"\n", optarg);
