@@ -305,6 +305,105 @@ char *latin4_syms[] = {
     "", "uogonek", "", "", "", "utilde", "umacron", ""
 };
 
+char *iso_8859_5_syms[] = { /* 160-255 */
+    "no-break_space",					/* 0240 */
+    "cyrillic_capital_letter_io",
+    "serbocroatian_cyrillic_capital_letter_dje",
+    "macedonian_cyrillic_capital_letter_gje",
+    "ukrainian_cyrillic_capital_letter_ie",
+    "macedonian_cyrillic_capital_letter_dze",
+    "cyrillic_capital_letter_i",
+    "ukrainian_cyrillic_capital_letter_yi",
+    "cyrillic_capital_letter_je", 			/* 0250 */
+    "cyrillic_capital_letter_lje",
+    "cyrillic_capital_letter_nje",
+    "serbocroatian_cyrillic_capital_letter_chje",
+    "macedonian_cyrillic_capital_letter_kje",
+    "soft_hyphen",
+    "bielorussian_cyrillic_capital_letter_short_u",
+    "cyrillic_capital_letter_dze",
+    "cyrillic_capital_letter_a", 			/* 0260 */
+    "cyrillic_capital_letter_be",
+    "cyrillic_capital_letter_ve",
+    "cyrillic_capital_letter_ghe",
+    "cyrillic_capital_letter_de",
+    "cyrillic_capital_letter_ie",
+    "cyrillic_capital_letter_zhe",
+    "cyrillic_capital_letter_ze",
+    "cyrillic_capital_letter_i", 			/* 0270 */
+    "cyrillic_capital_letter_short_i",
+    "cyrillic_capital_letter_ka",
+    "cyrillic_capital_letter_el",
+    "cyrillic_capital_letter_em",
+    "cyrillic_capital_letter_en",
+    "cyrillic_capital_letter_o",
+    "cyrillic_capital_letter_pe",
+    "cyrillic_capital_letter_er", 			/* 0300 */
+    "cyrillic_capital_letter_es",
+    "cyrillic_capital_letter_te",
+    "cyrillic_capital_letter_u",
+    "cyrillic_capital_letter_ef",
+    "cyrillic_capital_letter_ha",
+    "cyrillic_capital_letter_tse",
+    "cyrillic_capital_letter_che",
+    "cyrillic_capital_letter_sha", 			/* 0310 */
+    "cyrillic_capital_letter_shcha",
+    "cyrillic_capital_hard_sign",
+    "cyrillic_capital_letter_yeru",
+    "cyrillic_capital_soft_sign",
+    "cyrillic_capital_letter_e",
+    "cyrillic_capital_letter_yu",
+    "cyrillic_capital_letter_ya",
+    "cyrillic_small_letter_a",				/* 0320 */
+    "cyrillic_small_letter_be",
+    "cyrillic_small_letter_ve",
+    "cyrillic_small_letter_ghe",
+    "cyrillic_small_letter_de",
+    "cyrillic_small_letter_ie",
+    "cyrillic_small_letter_zhe",
+    "cyrillic_small_letter_ze",
+    "cyrillic_small_letter_i",				/* 0330 */
+    "cyrillic_small_letter_short_i",
+    "cyrillic_small_letter_ka",
+    "cyrillic_small_letter_el",
+    "cyrillic_small_letter_em",
+    "cyrillic_small_letter_en",
+    "cyrillic_small_letter_o",
+    "cyrillic_small_letter_pe",
+    "cyrillic_small_letter_er",				/* 0340 */
+    "cyrillic_small_letter_es",
+    "cyrillic_small_letter_te",
+    "cyrillic_small_letter_u",
+    "cyrillic_small_letter_ef",
+    "cyrillic_small_letter_ha",
+    "cyrillic_small_letter_tse",
+    "cyrillic_small_letter_che",
+    "cyrillic_small_letter_sha", 			/* 0350 */
+    "cyrillic_small_letter_shcha",
+    "cyrillic_small_hard_sign",
+    "cyrillic_small_letter_yeru",
+    "cyrillic_small_soft_sign",
+    "cyrillic_small_letter_e",
+    "cyrillic_small_letter_yu",
+    "cyrillic_small_letter_ya",
+    "number_acronym",					/* 0360 */
+    "cyrillic_small_letter_io",
+    "serbocroatian_cyrillic_small_letter_dje",
+    "macedonian_cyrillic_small_letter_gje",
+    "ukrainian_cyrillic_small_letter_ie",
+    "macedonian_cyrillic_small_letter_dze",
+    "cyrillic_small_letter_i",
+    "ukrainian_cyrillic_small_letter_yi",
+    "cyrillic_small_letter_je",				/* 0370 */
+    "cyrillic_small_letter_lje",
+    "cyrillic_small_letter_nje",
+    "serbocroatian_cyrillic_small_letter_chje",
+    "macedonian_cyrillic_small_letter_kje",
+    "paragraph_sign",
+    "bielorussian_cyrillic_small_letter_short_u", 	/* printing error in ECMA-113 */
+    "cyrillic_small_letter_dze"
+};
+
 char *iso_8859_7_syms[] = { /* 160-255 */
     "", "leftquote", "rightquote", "", "", "", "", "",
     "", "", "", "", "", "", "", "",
@@ -926,6 +1025,7 @@ struct cs {
     { "iso-8859-2", latin2_syms },
     { "iso-8859-3", latin3_syms },
     { "iso-8859-4", latin4_syms },
+    { "iso-8859-5", iso_8859_5_syms },
     { "iso-8859-7", iso_8859_7_syms },
     { "iso-8859-8", iso_8859_8_syms }
 };
